/*
 * generated Thu Mar 21 08:51:54 MDT 2024
 * on powerpc64-1.ports.openbsd.org (OpenBSD)
 * by $Id: configure,v 1.431 2024-01-01 04:06:59 phil Exp $
 */

#define CONFIG_OPTIONS "--prefix=/usr/local --opt=-O2 -pipe  "
#define CONFIG_HOST "powerpc64-1.ports.openbsd.org"
#define CONFIG_DATE "Thu Mar 21 08:51:54 MDT 2024"
#define DIR_SEP "/"
#define PATH_SEP ":"
#define OBJECT_EXT ".o"
#define SETUP_SYS "posix"
#define SHARED_OBJ_SUBDIR "shared"
#define PML_SERV
#define CC_IS "clang"
#define SIZEOF_LONG 8
#define NO_BITFIELDS
#define SIZLIM (~(VFLD_T)0)
#define REAL_T double
#define REALST_FORMAT "%.15lg"
#define SIZEOF_INT_T	8	/* for use in ifdefs */
#define SIZEOF_REAL_T	8	/* for use in ifdefs */
#define HAVE_UNISTD_H
#define HAVE_STDINT_H
#define HAVE_ISFINITE
#define GETRUSAGE_BUG
#define USE_MEMMOVE
#define HAVE_SOCKADDR_IN6
#define SOCKLEN_T socklen_t
/* vfork() in unistd.h */
#define TLS_IO
#define HAVE_UTIL_H
#define HAVE_PATHS_H
#define SNOLIB_BASE "/usr/local/lib/snobol4"
#define SNOLIB_DIR "/usr/local/lib/snobol4/2.3.2/lib"
#define INCLUDE_DIR "/usr/local/lib/snobol4/2.3.2/include"
#define HAVE_FSEEKO
#define HAVE_STRFTIME
#define EXPORT(TYPE) __attribute__ ((__visibility__("default"))) TYPE
/* Shared Object Libraries (in config.m4 too) */
#define SO_EXT ".so"
#define SO_CFLAGS "-fPIC -fvisibility=hidden"
#define SO_LD "cc"
#define SO_LDFLAGS "-shared -fPIC"
/* Dynamicly Loaded Extensions (in config.m4 too) */
#define DL_EXT ".so"
#define DL_CFLAGS "-fPIC"
#define DL_LD "cc"
#define DL_LDFLAGS "-shared -fPIC"
#define HAVE_READLINE
#define COMPILER_READLINE
#define HAVE_RL_SET_KEYMAP
#define USE_ZLIB
#define HAVE_NDBM_H
#define HAVE_LSTAT
#define USE_COMPIO
/* from CFLAGS: */
#define BLOCKS

/* if the file local-defines existed it would have been incorporated here */
